# Mypy Type Check Coverage Summary

Summary from index
File | Imprecision | Lines
--- | --- | ---
Total | 19.20% imprecise | 1146 LOC
hatch_ci | 0.00% imprecise | 2 LOC
hatch_ci.cli | 19.85% imprecise | 136 LOC
hatch_ci.common | 0.00% imprecise | 1 LOC
hatch_ci.hooks | 37.50% imprecise | 8 LOC
hatch_ci.scm | 11.39% imprecise | 281 LOC
hatch_ci.script | 27.75% imprecise | 173 LOC
hatch_ci.tools | 19.50% imprecise | 482 LOC
hatch_ci.version_hook | 25.40% imprecise | 63 LOC